pub struct Entity { /* private fields */ }Expand description
Lightweight unique ID, or handle, of an entity
Obtained from World::spawn. Can be stored to refer to an entity in the
future.
Enable the serde feature on the crate to make this Serializeable. Some
applications may be able to save space by only serializing the output of
Entity::id.
Implementations
Sourceimpl Entity
impl Entity
Sourcepub const DANGLING: Entity
pub const DANGLING: Entity
An Entity that does not necessarily correspond to data in any
World
Useful as a dummy value. It is possible (albeit unlikely) for a World
to contain this entity.
Sourcepub fn to_bits(self) -> NonZeroU64
pub fn to_bits(self) -> NonZeroU64
Convert to a form convenient for passing outside of rust
No particular structure is guaranteed for the returned bits.
Useful for storing entity IDs externally, or in conjunction with
Entity::from_bits and World::spawn_at for easy serialization.
Alternatively, consider id for more compact representation.
Sourcepub fn from_bits(bits: u64) -> Option<Self>
pub fn from_bits(bits: u64) -> Option<Self>
Reconstruct an Entity previously destructured with to_bits if the
bitpattern is valid, else None
Useful for storing entity IDs externally, or in conjunction with
Entity::to_bits and World::spawn_at for easy serialization.
Sourcepub fn id(self) -> u32
pub fn id(self) -> u32
Extract a transiently unique identifier
No two simultaneously-live entities share the same ID, but dead entities’ IDs may collide with both live and dead entities. Useful for compactly representing entities within a specific snapshot of the world, such as when serializing.
See also World::find_entity_from_id.