pub trait Component:
Send
+ Sync
+ 'static { }Expand description
Types that can be components, implemented automatically for all Send +
Sync
'statictypes
This is just a convenient shorthand for Send + Sync + 'static, and never
needs to be implemented manually.