pub struct Alignment(/* private fields */);Expand description
A type storing a usize which is a power of two, and thus
represents a possible alignment in the rust abstract machine.
Note that particularly large alignments, while representable in this type, are likely not to be supported by actual allocators and linkers.
Implementations
Sourceimpl Alignment
impl Alignment
Sourcepub const fn of<T>() -> Self
pub const fn of<T>() -> Self
Returns the alignment for a type.
This provides the same numerical value as mem::align_of,
but in an Alignment instead of a usize.
Sourcepub const fn new(align: usize) -> Option<Self>
pub const fn new(align: usize) -> Option<Self>
Creates an Alignment from a usize, or returns None if it’s
not a power of two.
Note that 0 is not a power of two, nor a valid alignment.
Sourcepub const unsafe fn new_unchecked(align: usize) -> Self
pub const unsafe fn new_unchecked(align: usize) -> Self
Creates an Alignment from a power-of-two usize.
Safety
align must be a power of two.
Equivalently, it must be 1 << exp for some exp in 0..usize::BITS.
It must not be zero.
Sourcepub const fn as_nonzero(self) -> NonZeroUsize
pub const fn as_nonzero(self) -> NonZeroUsize
Returns the alignment as a NonZeroUsize